extern void perform_moveword(rdp_command);
extern void perform_movemem(rdp_command);
extern void perform_dl(rdp_command, int);
extern void perform_setscissor(rdp_command);
extern void perform_setcimg(rdp_command);
extern void perform_setzimg(rdp_command);
extern void perform_settimg(rdp_command);
extern void perform_setfillcolor(rdp_command);
extern void perform_fillrect(rdp_command);
extern void perform_rdppipesync(rdp_command);
extern void perform_mtx(rdp_command);
extern void perform_vtx(rdp_command);
extern void perform_tri1(rdp_command);
extern void perform_spritebase(rdp_command);
extern void perform_cleargeometrymode(rdp_command);
extern void perform_texture(rdp_command);
extern void perform_setgeometrymode(rdp_command);
extern void perform_setothermode_h(rdp_command);
extern void perform_setothermode_l(rdp_command);
